JsDoc Reference - ColReorder#s

Generated by JsDoc Toolkit 2.4.0 on Wed Dec 15 2010 21:57:11 GMT-0000 (GMT)
HTML template: Codeview

# Namespace ColReorder#s

Settings object which contains customisable information for ColReorder instance
Defined in: ColReorder.js.

Namespace Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| ColReorder#s

Field Summary
Field Attributes | Field Name and Description
--- | ---
<static> | ColReorder#s.aoTargets Information which is used for positioning the insert cusor and knowing where to do the insert.
<static> | ColReorder#s.dt DataTables settings object
<static> | ColReorder#s.fixed Number of columns to fix (not allow to be reordered)
<static> | ColReorder#s.init Initialisation object used for this instance

Namespace Detail
ColReorder#s
Field Detail
<static> {array} ColReorder#s.aoTargets
Information which is used for positioning the insert cusor and knowing where to do the insert. Array of objects with the properties: x: x-axis position to: insert point

Default Value:
  []

<static> {Object} ColReorder#s.dt
DataTables settings object

Default Value:
  null

<static> {int} ColReorder#s.fixed
Number of columns to fix (not allow to be reordered)

Default Value:
  0

<static> {object} ColReorder#s.init
Initialisation object used for this instance